/**
 * Copyright (c) 2002 Bright Side Factory.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        Bright Side Factory (http://www.bs-factory.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "Bright Side", "BS Factory" and "Bright Side Factory" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact info@bs-factory.org.
 *
 * 5. Products derived from this software may not be called "Bright Side",
 *    nor may "Bright Side" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Bright Side Factory.  For more
 * information on the Bright Side Factory, please see
 * <http://www.bs-factory.org/>.
 */
package com.bsf.lovDemo.models;

import java.util.List;
import java.util.Vector;

/**
 * The model for the LOV Demo application. Some operations that, in a classical
 * application would be done using the server are here done locally since the
 * point is to illustrate the use of the lov and nothing else (for example the
 * retrieval of the Person object to display...).
 */
public class DemoModel {
    private List _persons = null;
    private PersonTableModel _tableModel = null;

    // *************************************************************************
    // ****************************** Constructor ******************************
    // *************************************************************************

    public DemoModel() {
        super();
    }

    // *************************************************************************
    // *************************** Instance Methods ****************************
    // *************************************************************************

    // *************************************************************************
    // ****************************** Accessors ********************************
    // *************************************************************************

    /**
     * @return a List of Persons.
     */
    public final List getPersons() {
        // Do we have to "retrieve" the Persons ?
        if ( _persons == null ) {
            // We do...
            retrievePersons();
        }

        return _persons;
    }

    /**
     * @return a Person object (usually to display in detail).
     */
    public final Person getPersonObject() {
        // We return the first Person (we KNOW we have 5 of them :o)
        return (Person) getPersons().get( 0 );
    }

    /**
     * @return a PersonTableModel containg the Person objects.
     */
    public final PersonTableModel getPersonTableModel() {
        if ( _tableModel == null ) {
            _tableModel = new PersonTableModel( getPersons() );
        }

        return _tableModel;
    }

    // *************************************************************************
    // ************************** Utility Methods ******************************
    // *************************************************************************

    /**
     * This method, in a real application, would probably be a remote call to
     * retrieve the Persons from the server.
     */
    protected void retrievePersons() {
        // Not needed here, just in case we later modify the application
        if ( _persons != null ) {
            _persons.clear();
        }

        _persons = new Vector();

        _persons.add( new Person( " CMX-127-09", " DUMAS Eric", new Long( 2 ) ) );
        _persons.add( new Person( " CMX-127-10", " FAULKER Katie", new Long( 2 ) ) );
        _persons.add( new Person( " CMX-127-11", " JOHNSON Mike", new Long( 1 ) ) );
        _persons.add( new Person( " CPR-133-01", " JOHNSON Vanessa", new Long( 2 ) ) );
        _persons.add( new Person( " DAX-133-02", " SMITH Joe", new Long( 3 ) ) );
        _persons.add( new Person( " DAX-136-07", " WEST Jim", new Long( 4 ) ) );
    }
}
