/**
 * Copyright (c) 2002 Bright Side Factory.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        Bright Side Factory (http://www.bs-factory.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "Bright Side", "BS Factory" and "Bright Side Factory" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact info@bs-factory.org.
 *
 * 5. Products derived from this software may not be called "Bright Side",
 *    nor may "Bright Side" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Bright Side Factory.  For more
 * information on the Bright Side Factory, please see
 * <http://www.bs-factory.org/>.
 */

package com.bsf.lovDemo.views.internalFrames;

import com.bsf.lovDemo.controllers.Actions;
import com.bsf.lovDemo.util.RollOverMouseAdapter;
import com.bsf.lovDemo.views.Resources;
import com.jgoodies.forms.layout.CellConstraints;
import com.jgoodies.forms.layout.FormLayout;
import com.jgoodies.swing.application.ActionManager;
import com.jgoodies.swing.application.ResourceManager;
import com.jgoodies.swing.panels.SimpleInternalFrame;

import javax.swing.*;
import java.awt.Color;

/**
 * Provides the getQuickStartInternalFrame view using a <code>SimpleInternalFrame</code>.
 */
public final class QuickStartInternalFrame extends SimpleInternalFrame {
    private Color BG_BUTTON_COLOR = new Color( 125, 150, 255 );

    // *************************************************************************
    // ***************************** Constructors ******************************
    // *************************************************************************

    /**
     * Constructs a <code>Navigator</code>.
     */
    public QuickStartInternalFrame() {
        super( ResourceManager.getString( "quickstart.title" ) );

        // We want this interfnal frame to appear selected
        setSelected( true );

        // We set the content of this internal frame
        setContent( buildActionPanel() );
    }

    // *************************************************************************
    // *************************** Design Methods ******************************
    // *************************************************************************

    /**
     * Builds and answers the action panel.
     */
    private JComponent buildActionPanel() {
        JPanel panel = new JPanel( new FormLayout(
                "F:pref:grow",
                "20dlu, 20dlu, 20dlu, 20dlu, 20dlu, fill:pref:grow" ) );

        panel.setOpaque( true );
        panel.setBackground( Color.white );

        CellConstraints cc = new CellConstraints();
        panel.add( createActionComponent( ActionManager.get( Actions.SHOW_WELCOME ) ), cc.xy( 1, 1 ) );
        panel.add( createActionComponent( ActionManager.get( Actions.SHOW_LOV_IN_TABLE ) ), cc.xy( 1, 2 ) );
        panel.add( createActionComponent( ActionManager.get( Actions.SHOW_LOV_COMBOBOX ) ), cc.xy( 1, 3 ) );
        panel.add( createActionComponent( ActionManager.get( Actions.SHOW_LOV_REQUEST_SETUP ) ), cc.xy( 1, 4 ) );
        panel.add( createActionComponent( ActionManager.get( Actions.SHOW_LOV_PERFORMANCES ) ), cc.xy( 1, 5 ) );

        return panel;
    }

    // *************************************************************************
    // ******************************* Accessors *******************************
    // *************************************************************************

    /**
     * Creates and answers a component for the specified <code>Action</code>.
     */
    private JComponent createActionComponent( Action a ) {
        JButton button = new JButton( a );

        button.setFocusPainted( false );
        button.setBorderPainted( false );
        button.setForeground( Color.black );
        button.setContentAreaFilled( false );
        button.setBackground( BG_BUTTON_COLOR );
        button.setHorizontalAlignment( SwingConstants.LEFT );
        button.setVerticalTextPosition( SwingConstants.CENTER );
        button.setHorizontalTextPosition( SwingConstants.RIGHT );
        button.setText( (String) a.getValue( Action.LONG_DESCRIPTION ) );
        button.setIcon( ResourceManager.getIcon( Resources.FORWARD_ICON_ID ) );

        // To have a little effect when the mouse enters or exit the button
        RollOverMouseAdapter.addRollOverMouseAdapter( button );

        return button;
    }
}