/**
 * Copyright (c) 2002 Bright Side Factory.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        Bright Side Factory (http://www.bs-factory.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "Bright Side", "BS Factory" and "Bright Side Factory" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact info@bs-factory.org.
 *
 * 5. Products derived from this software may not be called "Bright Side",
 *    nor may "Bright Side" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Bright Side Factory.  For more
 * information on the Bright Side Factory, please see
 * <http://www.bs-factory.org/>.
 */

package com.bsf.lovDemo.views.internalFrames;

import com.bsf.lovDemo.models.AvailableLovs;
import com.bsf.lovDemo.models.LovTableModel;
import com.jgoodies.forms.factories.DefaultComponentFactory;
import com.jgoodies.forms.layout.CellConstraints;
import com.jgoodies.forms.layout.FormLayout;
import com.jgoodies.swing.application.ResourceManager;
import com.jgoodies.swing.panels.GradientBackgroundPanel;
import com.jgoodies.swing.panels.SimpleInternalFrame;
import com.jgoodies.swing.util.UIFactory;
import org.bsf.listOfValues.client.LovManager;

import javax.swing.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

/**
 * Provides the InternalFrame for the ComboBoxes illustration.
 */
public final class SqlCustomizationInternalFrame extends SimpleInternalFrame implements ActionListener {
    private JTable _lovTable = null;
    private ButtonGroup _buttonGroup = null;
    private LovTableModel _countryTableModel = null;
    private LovTableModel _americanCountryAndRegionTableModel = null;

    private static final String COUNTRY = "COUNTRY";
    private static final String AMERICAN_COUNTRY_WITH_REGION_NAME = "AMERICAN_COUNTRY_WITH_REGION_NAME";

    {
        // We initialize the various models
        try {
            _countryTableModel = new LovTableModel( new String[]{"Field: Short Name", "Field: Long Name"},
                                                    new String[]{AvailableLovs.LOV_COUNTRIES_SHORT_NAME,
                                                                 AvailableLovs.LOV_COUNTRIES_LONG_NAME},
                                                    LovManager.getListOfValues( AvailableLovs.LOV_COUNTRIES ) );

            _americanCountryAndRegionTableModel = new LovTableModel( new String[]{"Field: Short Name", "Field: Long Name", "Field: Region Name"},
                                                                     new String[]{AvailableLovs.LOV_AMERICAN_COUNTRIES_WITH_REGION_NAME_SHORT_NAME,
                                                                                  AvailableLovs.LOV_AMERICAN_COUNTRIES_WITH_REGION_NAME_LONG_NAME,
                                                                                  AvailableLovs.LOV_AMERICAN_COUNTRIES_WITH_REGION_NAME_REGION_NAME},
                                                                     LovManager.getListOfValues( AvailableLovs.LOV_AMERICAN_COUNTRIES_WITH_REGION_NAME ) );
        } catch( Exception ex ) {
            // We can't do anything...
        }
    }


    // *************************************************************************
    // ***************************** Constructors ******************************
    // *************************************************************************

    /**
     * Constructs a module displaying the usage of LOVs in a Table.
     */
    public SqlCustomizationInternalFrame() {
        super( ResourceManager.getString( "sql.customization.title" ) );

        // We want this interfnal frame to appear selected
        setSelected( true );

        // We set the content of this internal frame
        try {
            setContent( buildContentPanel() );
        } catch( Exception e ) {
            // Should not happen... Lov Retrieval... Not here if impossible...
        }
    }

    // *************************************************************************
    // *************************** Design Methods ******************************
    // *************************************************************************

    /**
     * Builds and returns the content panel.
     */
    private JComponent buildContentPanel() throws Exception {
        _lovTable = new JTable( _countryTableModel );
        _lovTable.setOpaque( false );

        JScrollPane aScrollPane = UIFactory.createStrippedScrollPane( _lovTable );
        aScrollPane.setOpaque( false );
        aScrollPane.getViewport().setOpaque( false );

        JComponent sqlResultsSeparator = DefaultComponentFactory.getInstance().createSeparator( ResourceManager.getString( "resulting.sql.title" ) );
        sqlResultsSeparator.setOpaque( false );

        GradientBackgroundPanel enclosingPanel = new GradientBackgroundPanel( true );
        enclosingPanel.setLayout( new FormLayout( "3dlu, center:pref, 4dlu, fill:105dlu:none, 100dlu:grow, 3dlu",
                                                  "2dlu, center:pref, 5dlu, top:pref, 5dlu, top:1dlu:grow, top:pref" ) );

        CellConstraints cc = new CellConstraints();
        enclosingPanel.add( getAllLovSelectionPanel(), cc.xywh( 2, 2, 4, 1 ) );
        enclosingPanel.add( sqlResultsSeparator, cc.xywh( 2, 4, 4, 1 ) );
        enclosingPanel.add( aScrollPane, cc.xywh( 2, 6, 4, 1 ) );
        enclosingPanel.add( new JLabel( " " ), cc.xy( 2, 7 ) );

        return enclosingPanel;
    }

    private JPanel getAllLovSelectionPanel() {
        if ( _buttonGroup == null ) {
            _buttonGroup = _buttonGroup = new ButtonGroup();
        }

        JPanel aPanel = new JPanel( new FormLayout( "2dlu, center:pref:grow, 100dlu:grow, 2dlu",
                                                    "2dlu, pref:none, 3dlu, center:pref:none, 2dlu, center:pref:none, 2dlu" ) );
        aPanel.setOpaque( false );

        JComponent separator = DefaultComponentFactory.getInstance().createSeparator( ResourceManager.getString( "choose.sql.for.lov" ) );
        separator.setOpaque( false );

        CellConstraints cc = new CellConstraints();

        aPanel.add( separator, cc.xywh( 2, 2, 2, 1 ) );

        aPanel.add( getLovSelectionPanel( COUNTRY,
                                          AvailableLovs.HTML_SQL_LOV_COUNTRIES,
                                          AvailableLovs.HTML_SQL_LOV_COUNTRIES_TOOLTIP,
                                          true ),
                    cc.xywh( 2, 4, 2, 1 ) );

        aPanel.add( getLovSelectionPanel( AMERICAN_COUNTRY_WITH_REGION_NAME,
                                          AvailableLovs.HTML_SQL_LOV_AMERICAN_COUNTRIES_WITH_REGION_NAME,
                                          AvailableLovs.HTML_SQL_LOV_AMERICAN_COUNTRIES_WITH_REGION_NAME_TOOLTIP,
                                          false ),
                    cc.xywh( 2, 6, 2, 1 ) );

        return aPanel;
    }

    private JPanel getLovSelectionPanel( String p_actionCommand, String p_lovSQL, String p_tooltip, boolean p_isSelected ) {
        JLabel aLabel = new JLabel( p_lovSQL );
        if ( p_tooltip != null ) {
            aLabel.setToolTipText( p_tooltip );
        }

        JRadioButton aButton = new JRadioButton();
        aButton.setActionCommand( p_actionCommand );
        aButton.addActionListener( this );
        aButton.setOpaque( false );

        // We add it to the button group
        _buttonGroup.add( aButton );

        if ( p_isSelected ) {
            _buttonGroup.setSelected( aButton.getModel(), true );
        }

        JPanel aPanel = new JPanel( new FormLayout( "2dlu, left:pref:none, 5dlu, left:pref:grow, 100dlu, 2dlu", "2dlu, center:pref:none, 2dlu" ) );
        aPanel.setOpaque( false );

        CellConstraints cc = new CellConstraints();
        aPanel.add( aButton, cc.xy( 2, 2 ) );
        aPanel.add( aLabel, cc.xywh( 4, 2, 2, 1 ) );

        return aPanel;
    }

    /**
     * This action performed is called when a radio button is selected. It updates
     * the model of the table (the model is in cache for performance/memory issue).
     */
    public void actionPerformed( ActionEvent e ) {
        // Since the OID is the ActionCommand
        String command = _buttonGroup.getSelection().getActionCommand();

        try {
            // Just to show the user something happens since cause of the cache
            // the update would be too quick for the user to notice
            Thread.sleep( 250 );
        } catch( Exception e1 ) {
            // An error occured... We can't do anything... We leave the old lov
            // Shouldn't happen since the Lov are retrieved at startup...
            // No Lov -> No app !!!
        }

        LovTableModel tableModel = null;

        if ( COUNTRY == command ) {
            tableModel = _countryTableModel;
        } else if ( AMERICAN_COUNTRY_WITH_REGION_NAME == command ) {
            tableModel = _americanCountryAndRegionTableModel;
        }

        if ( tableModel != null ) {
            _lovTable.setModel( tableModel );
        } else {
            // We leave the current model...
        }
    }
}